Crate symbi_runtime

Crate symbi_runtime 

Symbiont Agent Runtime System

The Agent Runtime System is the core orchestration layer of the Symbiont platform, responsible for managing the complete lifecycle of autonomous agents.

Re-exports

pub use communication::CommunicationBus;
pub use communication::CommunicationConfig;
pub use communication::DefaultCommunicationBus;
pub use config::SecurityConfig;
pub use context::ContextManager;
pub use context::ContextManagerConfig;
pub use context::StandardContextManager;
pub use error_handler::DefaultErrorHandler;
pub use error_handler::ErrorHandler;
pub use error_handler::ErrorHandlerConfig;
pub use lifecycle::DefaultLifecycleController;
pub use lifecycle::LifecycleConfig;
pub use lifecycle::LifecycleController;
pub use logging::LoggingConfig;
pub use logging::ModelInteractionType;
pub use logging::ModelLogger;
pub use logging::RequestData;
pub use logging::ResponseData;
pub use models::ModelCatalog;
pub use models::ModelCatalogError;
pub use models::SlmRunner;
pub use models::SlmRunnerError;
pub use resource::DefaultResourceManager;
pub use resource::ResourceManager;
pub use resource::ResourceManagerConfig;
pub use routing::DefaultRoutingEngine;
pub use routing::RouteDecision;
pub use routing::RoutingConfig;
pub use routing::RoutingContext;
pub use routing::RoutingEngine;
pub use routing::TaskType;
pub use sandbox::E2BSandbox;
pub use sandbox::ExecutionResult;
pub use sandbox::SandboxRunner;
pub use sandbox::SandboxTier;
pub use scheduler::AgentScheduler;
pub use scheduler::DefaultAgentScheduler;
pub use scheduler::SchedulerConfig;
pub use secrets::SecretStore;
pub use secrets::SecretsConfig;
pub use types::*;

Modules

communication
Agent Communication Bus
config
Configuration management module for Symbiont runtime
context
Context management module for agent memory and knowledge systems
crypto
Cryptographic utilities for Symbiont
error_handler
Agent Error Handler
integrations
External Integration Interfaces
lifecycle
Agent Lifecycle Controller
logging
Encrypted Logging Module for Model I/O
metrics
Metrics collection and export for the Symbiont scheduler.
models
Model management module for Symbiont runtime
prelude
Prelude for standalone agent development.
rag
RAG (Retrieval-Augmented Generation) Engine Module
reasoning
Agentic Reasoning Loop
resource
Agent Resource Manager
routing
Policy-driven routing module for SLM-first architecture
sandbox
Sandbox abstraction layer for multi-tier sandbox execution
scheduler
Agent Runtime Scheduler
secrets
Symbiont Secure Secrets Integration
skills
toolclad
ToolClad: Declarative tool interface contracts
types
Core types and data structures for the Agent Runtime System

Structs

AgentRuntime
Main Agent Runtime System
RuntimeConfig
Runtime configuration