pub struct DefaultToolInvocationEnforcer { /* private fields */ }Expand description
Default implementation of tool invocation enforcement
Implementations
Sourceimpl DefaultToolInvocationEnforcer
impl DefaultToolInvocationEnforcer
Sourcepub fn with_config(config: InvocationEnforcementConfig) -> Self
pub fn with_config(config: InvocationEnforcementConfig) -> Self
Create a new tool invocation enforcer with custom configuration
Sourcepub fn with_logger(
config: InvocationEnforcementConfig,
logger: Arc<ModelLogger>,
) -> Self
pub fn with_logger( config: InvocationEnforcementConfig, logger: Arc<ModelLogger>, ) -> Self
Create a new tool invocation enforcer with model logging
Sourcepub fn with_routing(
config: InvocationEnforcementConfig,
logger: Option<Arc<ModelLogger>>,
routing_engine: Arc<dyn RoutingEngine>,
) -> Self
pub fn with_routing( config: InvocationEnforcementConfig, logger: Option<Arc<ModelLogger>>, routing_engine: Arc<dyn RoutingEngine>, ) -> Self
Create a new tool invocation enforcer with routing engine
Sourcepub fn with_mcp_client(
config: InvocationEnforcementConfig,
mcp_client: Arc<dyn McpClient>,
) -> Self
pub fn with_mcp_client( config: InvocationEnforcementConfig, mcp_client: Arc<dyn McpClient>, ) -> Self
Create a new tool invocation enforcer with an MCP client for real tool execution