pub struct DurableJournal { /* private fields */ }Expand description
Durable journal backed by a JournalStorage implementation.
Implements JournalWriter so it can be used as a drop-in replacement
for BufferedJournal in the reasoning loop.
Implementations
Sourceimpl DurableJournal
impl DurableJournal
Sourcepub fn new(storage: Arc<dyn JournalStorage>, agent_id: AgentId) -> Self
pub fn new(storage: Arc<dyn JournalStorage>, agent_id: AgentId) -> Self
Create a new durable journal for the given agent.
Sourcepub async fn initialize(&self) -> Result<(), JournalError>
pub async fn initialize(&self) -> Result<(), JournalError>
Initialize from storage, resuming the sequence counter.
Sourcepub async fn replay(&self) -> Result<Vec<JournalEntry>, JournalError>
pub async fn replay(&self) -> Result<Vec<JournalEntry>, JournalError>
Replay all journal entries for this agent.
Sourcepub async fn replay_from(
&self,
from_sequence: u64,
) -> Result<Vec<JournalEntry>, JournalError>
pub async fn replay_from( &self, from_sequence: u64, ) -> Result<Vec<JournalEntry>, JournalError>
Replay entries starting from a given sequence.
Sourcepub async fn compact(&self) -> Result<u64, JournalError>
pub async fn compact(&self) -> Result<u64, JournalError>
Compact (remove) all entries for this agent after successful loop completion.
Sourcepub async fn last_completed_iteration(&self) -> Result<u32, JournalError>
pub async fn last_completed_iteration(&self) -> Result<u32, JournalError>
Determine the last completed iteration from the journal.