pub struct DefaultRoutingEngine { /* private fields */ }Expand description
Default implementation of the routing engine
Implementations
Sourceimpl DefaultRoutingEngine
impl DefaultRoutingEngine
Sourcepub async fn new(
config: RoutingConfig,
model_catalog: ModelCatalog,
model_logger: Option<Arc<ModelLogger>>,
) -> Result<Self, RoutingError>
pub async fn new( config: RoutingConfig, model_catalog: ModelCatalog, model_logger: Option<Arc<ModelLogger>>, ) -> Result<Self, RoutingError>
Create a new routing engine with the given configuration
Sourcepub async fn new_with_confidence_monitor(
config: RoutingConfig,
model_catalog: ModelCatalog,
model_logger: Option<Arc<ModelLogger>>,
confidence_monitor: Box<dyn ConfidenceMonitorTrait>,
) -> Result<Self, RoutingError>
pub async fn new_with_confidence_monitor( config: RoutingConfig, model_catalog: ModelCatalog, model_logger: Option<Arc<ModelLogger>>, confidence_monitor: Box<dyn ConfidenceMonitorTrait>, ) -> Result<Self, RoutingError>
Create a new routing engine with a custom confidence monitor implementation This allows enterprise builds to inject their own confidence monitor